---
Title: Detector and Data Taking
Author: Jannik

Comment: Mainly based on LoI
---

## Detector

The KM3NeT Research Infrastructure will consist of a network of deep-sea neutrino detectors in the Mediterranean Sea with user ports for Earth and Sea sciences.

The KM3NeT neutrino detectors employ the same technology and neutrino detection principle, namely a three-dimensional array of photosensors that is used to detect Cherenkov light produced by relativistic particles emerging from neutrino interactions. From the arrival time of the Cherenkov photons (~nanosecond precision) and the position of the sensors (~10cm precision), the energy and direction of the incoming neutrino, as well as other parameters of the neutrino interaction, can be reconstructed. The main difference between different detector designs are the density of photosensors, which is optimised for the study of neutrinos in the few-GeV (ORCA) and TeV-PeV energy range (ARCA), respectively.

A key technology of the KM3NeT detectors is the Digital Optical Module (DOM), a pressure-resistant glass sphere housing 31 small 3-inch photo-multiplier tubes (PMTs), their associated electronics and calibration devices. The segmented photo-cathode of the multi-PMT design allows for uniform angular coverage, single-photon counting capabilities and directional information on the photon arrival direction. The DOMs are distributed in space along flexible strings, one end of which is fixed to the sea floor and the other end is held close to vertical by a submerged buoy. Each string comprises 18 DOMs. The strings are connected to junction boxes that provide connections for power and data transmission. 

A collection of 115 strings forms a single KM3NeT building block. The modular design allows building blocks with different spacings between strings/DOMs, in order to target different neutrino energies. In the KM3NeT Phase-2.0, three building blocks are foreseen: two KM3NeT/ARCA blocks, with a large spacing to target astrophysical neutrinos at TeV energies and above; and one KM3NeT/ORCA block, to target atmospheric neutrinos in the few-GeV range.

The ARCA (Astroparticle Research with Cosmics in the Abyss) detector is being installed at the KM3NeT-It site, 80km offshore the Sicilian coast offshore to Capo Passero (Italy) at a sea bottom depth of about 3450m. About 1 km^3 of seawater will be instrumented with ∼130,000PMTs.  The ORCA (Oscillation Research with Cosmics in the Abyss) detector is being installed at the KM3NeT-Fr site, 40km offshore Toulon (France) at a sea bottom depth of about 2450m. A volume of about 8 Mton is instrumented with ∼65,000PMTs. 

Technical details on the detector design are given in [1].

## Data Acquisition

The readout of the KM3NeT detector is based on the 'all-data-to-shore' concept, in which all analogue signals from the PMTs that pass a reference threshold are digitised. This data contain the time at which the analogue pulse crosses the threshold level, the time that the pulse remains above the threshold level (known as time-over-threshold, or ToT), and the PMT address. This is typically called a *hit*. All digital data (about 25 Gb/s per building block) are sent to a computing farm onshore where they are processed in real time. 
The recorded data is dominated by optical background noise from Cherenkov light from K40 decays in the seawater as well as bioluminescence from luminescent organisms in the deep sea. Events of scientific interest are filtered from the background using designated software, which exploit the time-position correlations following from causality. To maintain all available information for the offline analyses, each event contains a snapshot of all the data in the detector during the event. 

For calibration purposes summary data is written out, containing the count rates of all PMTs in the detector (with a sampling frequency of 10Hz). This information is used in the simulations as well as in the reconstruction to take into account the actual status and optical background conditions of the detector.

In parallel to the optical data, acoustic data and instrument data are recorded. The main purpose is position calibration of the DOMs, which is necessary as the detector elements can move under the influence of sea currents. The acoustic data includes the processed output from the piezo sensors in the DOMs and from the hydrophones in the base modules of the strings. The instrument data includes the processed output from the compasses, temperature sensors and humidity sensors inside the DOMs.

During operation the continuous data stream sent by the detector is split into small time intervals, called *runs*, with typical durations of a few hours. This is done for practical reasons of the data acquisition. In addition, this procedure allows to selected a set of run periods with high-quality data based on the monitored detector status, environmental conditions and data quality. The calibration for timing, positioning and photon detection efficiency is done offline using the calibration data. 


## Simulations

To assess the detector efficiency and systematics, dedicated Monte Carlo simulations are processed. Due to the changing data-taking conditions of the detector in the deep-sea environment, time-dependent simulation data-sets are required. These are implemented in a run-by-run simulation strategy, where runs are sufficiently small time intervals of data taking with stable conditions. The detector response is simulated individually for these periods. The simulation data are generated at the raw-data level and are subjected to the same filter and reconstruction processing as the real data. Since large statistics are required for precise analyses, the simulation data will significantly exceed the real data in volume.

   

-----------
[1] [Adrian-Martnez S et al (KM3NeT Collaboration) 2016 J. Phys. G 43 084001](https://iopscience.iop.org/article/10.1088/0954-3899/43/8/084001)    


